@@ -14,24 +14,22 @@ from __future__ import print_function
 
 import logging
 
-from reno import scanner
-from reno import utils
+from reno import loader
 
 LOG = logging.getLogger(__name__)
 
 
-def list_cmd(args):
+def list_cmd(args, conf):
     "List notes files based on query arguments"
     LOG.debug('starting list')
-    reporoot = args.reporoot.rstrip('/') + '/'
-    notesdir = utils.get_notes_dir(args)
-    notes = scanner.get_notes_by_version(reporoot, notesdir, args.branch)
+    reporoot = conf.reporoot
+    ldr = loader.Loader(conf)
     if args.version:
         versions = args.version
     else:
-        versions = notes.keys()
+        versions = ldr.versions
     for version in versions:
-        notefiles = notes[version]
+        notefiles = ldr[version]
         print(version)
         for n, sha in notefiles:
             if n.startswith(reporoot):
