@@ -13,24 +13,22 @@
 from __future__ import print_function
 
 from reno import formatter
-from reno import scanner
-from reno import utils
+from reno import loader
 
 
-def report_cmd(args):
+def report_cmd(args, conf):
     "Generates a release notes report"
-    reporoot = args.reporoot.rstrip('/') + '/'
-    notesdir = utils.get_notes_dir(args)
-    notes = scanner.get_notes_by_version(reporoot, notesdir, args.branch)
+    ldr = loader.Loader(conf)
     if args.version:
         versions = args.version
     else:
-        versions = notes.keys()
+        versions = ldr.versions
     text = formatter.format_report(
-        reporoot,
-        notes,
+        ldr,
+        conf,
         versions,
-        title='Release Notes',
+        title=args.title,
+        show_source=args.show_source,
     )
     if args.output:
         with open(args.output, 'w') as f:
